function P = bigseg(Thres, CovData)
%regel van bayes
%P(i,1) geven de noemers van de gezamelijke probabiliteiten
%P(i,2) geven de tellers van de gezamelijke probabiliteiten

SAMPLES = 2000000;
CovLength = size(CovData,1);

%data generatie voor de gepaste dimensie met gepaste covariantie
X = randn(CovLength, SAMPLES);
C = chol(CovData);
X = (C'*X);

% =======================================
% iedere segment met een niet-straatpixel
% =======================================
for SegL = 1:(CovLength+1)/2
    %eerste threshold: de noemer, met centraal straatpixel
    Seg = ones(1,SegL);
    Seg(SegL) = 0;% Seg representeert de sequentie van straatpxls met halve venstergrootte
    Threshold = [Thres 1];
    Threshold = Threshold(ones(1,CovLength),:);
    Threshold(1:(CovLength+1)/2-1, 2) = 0;
    Threshold((CovLength+1)/2+length(Seg):CovLength,2) = 0;
    for j = 1:length(Seg)
        if Seg(j) == 0
            Threshold((CovLength+1)/2+j-1,2) = -1;
        end;
    end;
    T = Threshold;
    % alles omzetten naar groter dan voorwaarden, en omzetten van de
    % marginalisatie, door een zeer lage drempel
    for i = 1:CovLength
        if T(i,2) < 0 
            X(i,:) = -X(i,:);
            T(i,1) = -T(i,1);
        end
        if T(i,2) == 0;
            T(i,1) = -100;
        end
    end
    
    % de grenzen zetten voor iedere element van X
    T = T(:,1);
    T = T(:,ones(1,SAMPLES));
    
    % verificatie van grens en tellen
    T = X > T;
    if CovLength > 1
        T = sum(T);
    end;
    P(SegL,1) = sum(T==CovLength)/SAMPLES; 
    
    % data restaureren
    for i = 1:CovLength
        if Threshold(i,2) < 0 
            X(i,:) = -X(i,:);
        end
    end
    
    %tweede threshold: de teller, met centrale integratie (Seg schuift 1
    %pixel op naar rechts)
    Threshold = [Thres 1];
    Threshold = Threshold(ones(1,CovLength),:);
    Threshold(1:(CovLength+1)/2, 2) = 0;
    if SegL ~= (CovLength+1)/2 %indien niet vervult: de noemer van de groeifactor heeft geen niet-straatpixel meer 
        Threshold((CovLength+1)/2+1+length(Seg):CovLength,2) = 0;
        for j = 1:length(Seg)
            if Seg(j) == 0
                Threshold((CovLength+1)/2+j,2) = -1;
            end;
        end;
    end;
        
    T = Threshold;
    % alles omzetten naar groter dan voorwaarden
    for i = 1:CovLength
        if T(i,2) < 0 
            X(i,:) = -X(i,:);
            T(i,1) = -T(i,1);
        end
        if T(i,2) == 0;
            T(i,1) = -100;
        end
    end
    
    % de grenzen zetten voor iedere element van X
    T = T(:,1);
    T = T(:,ones(1,SAMPLES));
    
    % verificatie van grens en tellen
    T = X > T;
    if CovLength > 1
        T = sum(T);
    end;
    P(SegL+1,2) = sum(T==CovLength)/SAMPLES; 
    
    % data restaureren
    for i = 1:CovLength
        if Threshold(i,2) < 0 
            X(i,:) = -X(i,:);
        end
    end
end
% ==============================================
% de probabiliteitsnoemer met enkel straatpixels
% ==============================================
Threshold = [Thres 1];
Threshold = Threshold(ones(1,CovLength),:);
Threshold(1:(CovLength-1)/2, 2) = 0;
T = Threshold;
for i = 1:CovLength
    if T(i,2) < 0 
        X(i,:) = -X(i,:);
        T(i,1) = -T(i,1);
    end
    if T(i,2) == 0;
        T(i,1) = -100;
    end
end
% de grenzen zetten voor iedere element van X
T = T(:,1);
T = T(:,ones(1,SAMPLES));

% verificatie van grens en tellen
T = X > T;
if CovLength > 1
    T = sum(T);
end;
P((CovLength+1)/2+1,1) = sum(T==CovLength)/SAMPLES; 

% ================================================
% de laatste factor ter aflsuiting van het segment
% ================================================
Threshold = [Thres 1];
Threshold = Threshold(ones(1,CovLength),:);
Threshold(1:(CovLength+1)/2, 2) = 0;
Threshold((CovLength+1)/2, 2) = -1;
T = Threshold;
for i = 1:CovLength
    if T(i,2) < 0 
        X(i,:) = -X(i,:);
        T(i,1) = -T(i,1);
    end
    if T(i,2) == 0;
        T(i,1) = -100;
    end
end
% de grenzen zetten voor iedere element van X
T = T(:,1);
T = T(:,ones(1,SAMPLES));

% verificatie van grens en tellen
T = X > T;
if CovLength > 1
    T = sum(T);
end;
P((CovLength+1)/2+2,1) = sum(T==CovLength)/SAMPLES; 
P((CovLength+1)/2+2,2) = P((CovLength+1)/2+1,2);