function [out] = ridgedetect(image,w,outflag)

%

% ridge detector using facet method with window size w

%   outflag = 1 : output is coefficient band image

%                   out is a 6 bands image containing the facet coefficients a1...a6

%   outflag = 2 : output is grad/eig band image

%                   out is a 3 bands image containing gradient, max eigenvalue and min eigenvalue (in this order)

%   



rows = size(image,1);

cols = size(image,2);



if (outflag==1)

    outimage = zeros(rows,cols,6);

else

    band     = zeros(3,1);
    outimage = zeros(rows,cols,3);

end;



% ===========================================

% Create matrix A for given window size w

% ===========================================



halfw = floor(w/2);

for y = -halfw:halfw

	for x = -halfw:halfw

		A(((y+halfw)*w)+(x+halfw+1),1) = 1;

		A(((y+halfw)*w)+(x+halfw+1),2) = x;

		A(((y+halfw)*w)+(x+halfw+1),3) = y;

		A(((y+halfw)*w)+(x+halfw+1),4) = x^2;

		A(((y+halfw)*w)+(x+halfw+1),5) = x*y;

		A(((y+halfw)*w)+(x+halfw+1),6) = y^2;

	end

end



% ===========================================

% Process each pixel

% ===========================================

for i=halfw+1:rows-halfw;

    for j=halfw+1:cols-halfw;

        

        %% fill intensity vector b

        for y = -halfw:halfw

        	for x = -halfw:halfw

                b(((y+halfw)*w)+(x+halfw+1)) = double(image(i+y,j+x));

            end;

        end;



        theta = A\b';

        if (outflag==1)

            outimage(i,j,:) = theta;

        else

            band(1) = sqrt(theta(2)^2 + theta(3)^2);

            l1 = theta(4) + theta(6) + sqrt((theta(4)-theta(6))^2 + theta(5)^2);

            l2 = theta(4) + theta(6) - sqrt((theta(4)-theta(6))^2 + theta(5)^2);

            if (abs(l1)>abs(l2)) 

                band(2) = l1;

                band(3) = l2;

            else

                band(2) = l2;

                band(3) = l1;

            end;

            outimage(i,j,:) = band;

        end;

    end;

end;



out = outimage;

        